@@ -3,8 +3,9 @@ import re
 import boto3
 import pytest
 
-from moto import mock_applicationautoscaling, mock_ecs
+from moto import mock_aws
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
+from tests.test_dynamodb import dynamodb_aws_verified
 
 DEFAULT_REGION = "us-east-1"
 DEFAULT_ECS_CLUSTER = "default"
@@ -50,8 +51,34 @@ def _create_ecs_defaults(ecs, create_service=True):
         )
 
 
-@mock_ecs
-@mock_applicationautoscaling
+def delete_scheduled_actions():
+    service_namespaces = ["custom-resource", "dynamodb", "ecs"]
+    client = boto3.client("application-autoscaling", region_name=DEFAULT_REGION)
+
+    for namespace in service_namespaces:
+        actions = client.describe_scheduled_actions(ServiceNamespace=namespace)[
+            "ScheduledActions"
+        ]
+        for a in actions:
+            client.delete_scheduled_action(
+                ServiceNamespace=namespace,
+                ScheduledActionName=a["ScheduledActionName"],
+                ResourceId=a["ResourceId"],
+                ScalableDimension=a["ScalableDimension"],
+            )
+
+        targets = client.describe_scalable_targets(ServiceNamespace=namespace)[
+            "ScalableTargets"
+        ]
+        for t in targets:
+            client.deregister_scalable_target(
+                ServiceNamespace=namespace,
+                ResourceId=t["ResourceId"],
+                ScalableDimension=t["ScalableDimension"],
+            )
+
+
+@mock_aws
 def test_describe_scalable_targets_one_basic_ecs_success():
     ecs = boto3.client("ecs", region_name=DEFAULT_REGION)
     _create_ecs_defaults(ecs)
@@ -73,8 +100,7 @@ def test_describe_scalable_targets_one_basic_ecs_success():
     assert "CreationTime" in t
 
 
-@mock_ecs
-@mock_applicationautoscaling
+@mock_aws
 def test_describe_scalable_targets_one_full_ecs_success():
     ecs = boto3.client("ecs", region_name=DEFAULT_REGION)
     _create_ecs_defaults(ecs)
@@ -99,8 +125,7 @@ def test_describe_scalable_targets_one_full_ecs_success():
     )
 
 
-@mock_ecs
-@mock_applicationautoscaling
+@mock_aws
 def test_describe_scalable_targets_only_return_ecs_targets():
     ecs = boto3.client("ecs", region_name=DEFAULT_REGION)
     _create_ecs_defaults(ecs, create_service=False)
@@ -140,8 +165,7 @@ def test_describe_scalable_targets_only_return_ecs_targets():
     assert len(response["ScalableTargets"]) == 2
 
 
-@mock_ecs
-@mock_applicationautoscaling
+@mock_aws
 def test_describe_scalable_targets_next_token_success():
     ecs = boto3.client("ecs", region_name=DEFAULT_REGION)
     _create_ecs_defaults(ecs, create_service=False)
@@ -187,8 +211,7 @@ def register_scalable_target(client, **kwargs):
     )
 
 
-@mock_ecs
-@mock_applicationautoscaling
+@mock_aws
 def test_register_scalable_target_resource_id_variations():
     # Required to register an ECS target in moto
     ecs = boto3.client("ecs", region_name=DEFAULT_REGION)
@@ -266,8 +289,7 @@ def test_register_scalable_target_resource_id_variations():
         assert "CreationTime" in t
 
 
-@mock_ecs
-@mock_applicationautoscaling
+@mock_aws
 def test_register_scalable_target_updates_existing_target():
     ecs = boto3.client("ecs", region_name=DEFAULT_REGION)
     _create_ecs_defaults(ecs)
@@ -282,7 +304,7 @@ def test_register_scalable_target_updates_existing_target():
         "ScheduledScalingSuspended": False,
     }
 
-    client.register_scalable_target(
+    response = client.register_scalable_target(
         ServiceNamespace=DEFAULT_SERVICE_NAMESPACE,
         ResourceId=DEFAULT_RESOURCE_ID,
         ScalableDimension=DEFAULT_SCALABLE_DIMENSION,
@@ -290,12 +312,16 @@ def test_register_scalable_target_updates_existing_target():
         MaxCapacity=updated_max_capacity,
         SuspendedState=updated_suspended_state,
     )
+    expected_arn_prefix = f"arn:aws:application-autoscaling:{DEFAULT_REGION}:{ACCOUNT_ID}:scalable-target/"
+    assert response["ScalableTargetARN"].startswith(expected_arn_prefix)
+
     response = client.describe_scalable_targets(
         ServiceNamespace=DEFAULT_SERVICE_NAMESPACE
     )
 
     assert len(response["ScalableTargets"]) == 1
     t = response["ScalableTargets"][0]
+    assert t["ScalableTargetARN"].startswith(expected_arn_prefix)
     assert t["MinCapacity"] == updated_min_capacity
     assert t["MaxCapacity"] == updated_max_capacity
     assert (
@@ -312,81 +338,7 @@ def test_register_scalable_target_updates_existing_target():
     )
 
 
-@pytest.mark.parametrize(
-    ["policy_type", "policy_body_kwargs"],
-    [
-        [
-            "TargetTrackingScaling",
-            {
-                "TargetTrackingScalingPolicyConfiguration": {
-                    "TargetValue": 70.0,
-                    "PredefinedMetricSpecification": {
-                        "PredefinedMetricType": "SageMakerVariantInvocationsPerInstance"
-                    },
-                }
-            },
-        ],
-        [
-            "TargetTrackingScaling",
-            {
-                "StepScalingPolicyConfiguration": {
-                    "AdjustmentType": "ChangeCapacity",
-                    "StepAdjustments": [{"ScalingAdjustment": 10}],
-                    "MinAdjustmentMagnitude": 2,
-                },
-            },
-        ],
-    ],
-)
-@mock_applicationautoscaling
-def test_put_scaling_policy(policy_type, policy_body_kwargs):
-    client = boto3.client("application-autoscaling", region_name=DEFAULT_REGION)
-    namespace = "sagemaker"
-    resource_id = "endpoint/MyEndPoint/variant/MyVariant"
-    scalable_dimension = "sagemaker:variant:DesiredInstanceCount"
-
-    client.register_scalable_target(
-        ServiceNamespace=namespace,
-        ResourceId=resource_id,
-        ScalableDimension=scalable_dimension,
-        MinCapacity=1,
-        MaxCapacity=8,
-    )
-
-    policy_name = "MyPolicy"
-
-    with pytest.raises(client.exceptions.ValidationException) as e:
-        client.put_scaling_policy(
-            PolicyName=policy_name,
-            ServiceNamespace=namespace,
-            ResourceId=resource_id,
-            ScalableDimension=scalable_dimension,
-            PolicyType="ABCDEFG",
-            **policy_body_kwargs,
-        )
-    assert (
-        e.value.response["Error"]["Message"] == "Unknown policy type ABCDEFG specified."
-    )
-
-    response = client.put_scaling_policy(
-        PolicyName=policy_name,
-        ServiceNamespace=namespace,
-        ResourceId=resource_id,
-        ScalableDimension=scalable_dimension,
-        PolicyType=policy_type,
-        **policy_body_kwargs,
-    )
-    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
-    assert (
-        re.match(
-            pattern=rf"arn:aws:autoscaling:{DEFAULT_REGION}:{ACCOUNT_ID}:scalingPolicy:.*:resource/{namespace}/{resource_id}:policyName/{policy_name}",
-            string=response["PolicyARN"],
-        )
-        is not None
-    )
-
-
-@mock_applicationautoscaling
+@mock_aws
 def test_describe_scaling_policies():
     client = boto3.client("application-autoscaling", region_name=DEFAULT_REGION)
     namespace = "sagemaker"
@@ -444,7 +396,7 @@ def test_describe_scaling_policies():
     assert "CreationTime" in policy
 
 
-@mock_applicationautoscaling
+@mock_aws
 def test_delete_scaling_policies():
     client = boto3.client("application-autoscaling", region_name=DEFAULT_REGION)
     namespace = "sagemaker"
@@ -505,7 +457,7 @@ def test_delete_scaling_policies():
     assert len(response["ScalingPolicies"]) == 0
 
 
-@mock_applicationautoscaling
+@mock_aws
 def test_deregister_scalable_target():
     client = boto3.client("application-autoscaling", region_name=DEFAULT_REGION)
     namespace = "sagemaker"
@@ -541,7 +493,7 @@ def test_deregister_scalable_target():
     assert "No scalable target found" in e.value.response["Error"]["Message"]
 
 
-@mock_applicationautoscaling
+@mock_aws
 def test_delete_scheduled_action():
     client = boto3.client("application-autoscaling", region_name="eu-west-1")
     resp = client.describe_scheduled_actions(ServiceNamespace="ecs")
@@ -569,7 +521,7 @@ def test_delete_scheduled_action():
     assert len(resp["ScheduledActions"]) == 2
 
 
-@mock_applicationautoscaling
+@mock_aws
 def test_describe_scheduled_actions():
     client = boto3.client("application-autoscaling", region_name="eu-west-1")
     resp = client.describe_scheduled_actions(ServiceNamespace="ecs")
@@ -615,33 +567,74 @@ def test_describe_scheduled_actions():
     assert len(resp["ScheduledActions"]) == 0
 
 
-@mock_applicationautoscaling
-def test_put_scheduled_action():
-    client = boto3.client("application-autoscaling", region_name="ap-southeast-1")
-    client.put_scheduled_action(
-        ServiceNamespace="ecs",
-        ScheduledActionName="action_name",
-        ResourceId="ecs:cluster:x",
-        ScalableDimension="ecs:service:DesiredCount",
-    )
+@dynamodb_aws_verified()
+@pytest.mark.aws_verified
+def test_put_scheduled_action(table_name=None):
+    client = boto3.client("application-autoscaling", region_name="us-east-1")
+    try:
+        resource_id = f"table/{table_name}"
+        client.register_scalable_target(
+            ServiceNamespace="dynamodb",
+            ResourceId=resource_id,
+            ScalableDimension="dynamodb:table:ReadCapacityUnits",
+            MinCapacity=1,
+            MaxCapacity=100,
+        )
+        client.put_scheduled_action(
+            ServiceNamespace="dynamodb",
+            Schedule="rate(2 minutes)",
+            ScheduledActionName="action_name",
+            ResourceId=resource_id,
+            ScalableDimension="dynamodb:table:ReadCapacityUnits",
+            ScalableTargetAction={"MinCapacity": 1, "MaxCapacity": 5},
+        )
 
-    resp = client.describe_scheduled_actions(ServiceNamespace="ecs")
-    assert len(resp["ScheduledActions"]) == 1
+        resp = client.describe_scheduled_actions(ServiceNamespace="dynamodb")
+        assert len(resp["ScheduledActions"]) == 1
 
-    action = resp["ScheduledActions"][0]
-    assert action["ScheduledActionName"] == "action_name"
-    assert (
-        action["ScheduledActionARN"]
-        == f"arn:aws:autoscaling:ap-southeast-1:{ACCOUNT_ID}:scheduledAction:ecs:scheduledActionName/action_name"
-    )
-    assert action["ServiceNamespace"] == "ecs"
-    assert action["ResourceId"] == "ecs:cluster:x"
-    assert action["ScalableDimension"] == "ecs:service:DesiredCount"
-    assert "CreationTime" in action
-    assert "ScalableTargetAction" not in action
+        action = resp["ScheduledActions"][0]
+        assert action["ScheduledActionName"] == "action_name"
+        assert action["ServiceNamespace"] == "dynamodb"
+        assert action["ResourceId"] == resource_id
+        assert action["ScalableDimension"] == "dynamodb:table:ReadCapacityUnits"
+        assert "CreationTime" in action
+
+        # Verify it's possible to create a second action against the same Dimension
+        client.put_scheduled_action(
+            ServiceNamespace="dynamodb",
+            Schedule="rate(1 hour)",
+            ScheduledActionName="action_name2",
+            ResourceId=resource_id,
+            ScalableDimension="dynamodb:table:ReadCapacityUnits",
+            ScalableTargetAction={"MinCapacity": 1, "MaxCapacity": 5},
+        )
+        actions = client.describe_scheduled_actions(ServiceNamespace="dynamodb")[
+            "ScheduledActions"
+        ]
+        assert len(actions) == 2
+
+        action1 = [a for a in actions if a["ScheduledActionName"] == "action_name"][0]
+        action2 = [a for a in actions if a["ScheduledActionName"] == "action_name2"][0]
+
+        assert action1["ResourceId"] == resource_id
+        assert action2["ResourceId"] == resource_id
+
+        # AWS includes a random ID
+        # arn:aws:autoscaling:us-east-1:{ACCOUNT_ID}:scheduledAction:2e767478-3c94-463b-8d0c-5a5fb3ee04cf:resource/dynamodb/table/{table_name}:scheduledActionName/action_name
+        assert action1["ScheduledActionARN"].endswith(
+            f"dynamodb/table/{table_name}:scheduledActionName/action_name"
+        )
+        assert action2["ScheduledActionARN"].endswith(
+            f"dynamodb/table/{table_name}:scheduledActionName/action_name2"
+        )
+
+        assert action1["Schedule"] == "rate(2 minutes)"
+        assert action2["Schedule"] == "rate(1 hour)"
+    finally:
+        delete_scheduled_actions()
 
 
-@mock_applicationautoscaling
+@mock_aws
 def test_put_scheduled_action__use_update():
     client = boto3.client("application-autoscaling", region_name="ap-southeast-1")
     client.put_scheduled_action(
@@ -652,7 +645,7 @@ def test_put_scheduled_action__use_update():
     )
     client.put_scheduled_action(
         ServiceNamespace="ecs",
-        ScheduledActionName="action_name_updated",
+        ScheduledActionName="action_name",
         ResourceId="ecs:cluster:x",
         ScalableDimension="ecs:service:DesiredCount",
         ScalableTargetAction={
@@ -665,10 +658,10 @@ def test_put_scheduled_action__use_update():
     assert len(resp["ScheduledActions"]) == 1
 
     action = resp["ScheduledActions"][0]
-    assert action["ScheduledActionName"] == "action_name_updated"
+    assert action["ScheduledActionName"] == "action_name"
     assert (
         action["ScheduledActionARN"]
-        == f"arn:aws:autoscaling:ap-southeast-1:{ACCOUNT_ID}:scheduledAction:ecs:scheduledActionName/action_name"
+        == f"arn:aws:autoscaling:ap-southeast-1:{ACCOUNT_ID}:scheduledAction:ecs/ecs:cluster:x:scheduledActionName/action_name"
     )
     assert action["ServiceNamespace"] == "ecs"
     assert action["ResourceId"] == "ecs:cluster:x"
