@@ -1,18 +1,18 @@
+from datetime import datetime
 from uuid import uuid4
 
 import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_autoscaling, mock_ec2
+from moto import mock_aws
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
-from tests import EXAMPLE_AMI_ID
+from tests import EXAMPLE_AMI_ID, aws_verified
 
 from .utils import setup_instance_with_networking, setup_networking
 
 
-@mock_autoscaling
-@mock_ec2
+@mock_aws
 def test_propogate_tags():
     mocked_networking = setup_networking()
     conn = boto3.client("autoscaling", region_name="us-east-1")
@@ -47,7 +47,7 @@ def test_propogate_tags():
     assert {"Value": "TestGroup1", "Key": "aws:autoscaling:groupName"} in tags
 
 
-@mock_autoscaling
+@mock_aws
 def test_create_autoscaling_group_from_instance():
     autoscaling_group_name = "test_asg"
     image_id = EXAMPLE_AMI_ID
@@ -76,8 +76,7 @@ def test_create_autoscaling_group_from_instance():
     assert config["InstanceType"] == instance_type
 
 
-@mock_autoscaling
-@mock_ec2
+@mock_aws
 def test_create_autoscaling_group_from_instance_with_security_groups():
     autoscaling_group_name = "test_asg"
     image_id = EXAMPLE_AMI_ID
@@ -107,7 +106,7 @@ def test_create_autoscaling_group_from_instance_with_security_groups():
     assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
 
 
-@mock_autoscaling
+@mock_aws
 def test_create_autoscaling_group_from_invalid_instance_id():
     invalid_instance_id = "invalid_instance"
 
@@ -129,8 +128,7 @@ def test_create_autoscaling_group_from_invalid_instance_id():
     assert err["Message"] == f"Instance [{invalid_instance_id}] is invalid."
 
 
-@mock_autoscaling
-@mock_ec2
+@mock_aws
 def test_create_autoscaling_group_from_template():
     mocked_networking = setup_networking()
 
@@ -155,8 +153,7 @@ def test_create_autoscaling_group_from_template():
     assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
 
 
-@mock_ec2
-@mock_autoscaling
+@mock_aws
 def test_create_auto_scaling_from_template_version__latest():
     ec2_client = boto3.client("ec2", region_name="us-west-1")
     launch_template_name = "tester"
@@ -185,8 +182,7 @@ def test_create_auto_scaling_from_template_version__latest():
     assert response["LaunchTemplate"]["Version"] == "$Latest"
 
 
-@mock_ec2
-@mock_autoscaling
+@mock_aws
 def test_create_auto_scaling_from_template_version__default():
     ec2_client = boto3.client("ec2", region_name="us-west-1")
     launch_template_name = "tester"
@@ -220,8 +216,7 @@ def test_create_auto_scaling_from_template_version__default():
     assert response["LaunchTemplate"]["Version"] == "$Default"
 
 
-@mock_ec2
-@mock_autoscaling
+@mock_aws
 def test_create_auto_scaling_from_template_version__no_version():
     ec2_client = boto3.client("ec2", region_name="us-west-1")
     launch_template_name = "tester"
@@ -247,8 +242,7 @@ def test_create_auto_scaling_from_template_version__no_version():
     assert "Version" not in response["LaunchTemplate"]
 
 
-@mock_autoscaling
-@mock_ec2
+@mock_aws
 def test_create_autoscaling_group_no_template_ref():
     mocked_networking = setup_networking()
 
@@ -278,8 +272,7 @@ def test_create_autoscaling_group_no_template_ref():
     )
 
 
-@mock_autoscaling
-@mock_ec2
+@mock_aws
 def test_create_autoscaling_group_multiple_template_ref():
     mocked_networking = setup_networking()
 
@@ -313,7 +306,7 @@ def test_create_autoscaling_group_multiple_template_ref():
     )
 
 
-@mock_autoscaling
+@mock_aws
 def test_create_autoscaling_group_no_launch_configuration():
     mocked_networking = setup_networking()
     client = boto3.client("autoscaling", region_name="us-east-1")
@@ -335,8 +328,7 @@ def test_create_autoscaling_group_no_launch_configuration():
     )
 
 
-@mock_autoscaling
-@mock_ec2
+@mock_aws
 def test_create_autoscaling_group_multiple_launch_configurations():
     mocked_networking = setup_networking()
 
@@ -375,8 +367,7 @@ def test_create_autoscaling_group_multiple_launch_configurations():
     )
 
 
-@mock_autoscaling
-@mock_ec2
+@mock_aws
 def test_describe_autoscaling_groups_launch_template():
     mocked_networking = setup_networking()
     ec2_client = boto3.client("ec2", region_name="us-east-1")
@@ -417,7 +408,57 @@ def test_describe_autoscaling_groups_launch_template():
         assert instance["InstanceType"] == "t2.micro"
 
 
-@mock_autoscaling
+@mock_aws
+def test_describe_autoscaling_groups_launch_template_with_block_device_mappings():
+    mocked_networking = setup_networking()
+    ec2_client = boto3.client("ec2", region_name="us-east-1")
+    ec2_client.create_launch_template(
+        LaunchTemplateName="test_launch_template",
+        LaunchTemplateData={
+            "ImageId": EXAMPLE_AMI_ID,
+            "InstanceType": "t2.micro",
+            "BlockDeviceMappings": [
+                {
+                    "DeviceName": "/dev/sda1",
+                    "Ebs": {
+                        "VolumeSize": 20,
+                        "DeleteOnTermination": True,
+                        "VolumeType": "gp3",
+                        "Encrypted": True,
+                    },
+                }
+            ],
+        },
+    )
+    client = boto3.client("autoscaling", region_name="us-east-1")
+    client.create_auto_scaling_group(
+        AutoScalingGroupName="test_asg",
+        LaunchTemplate={"LaunchTemplateName": "test_launch_template", "Version": "1"},
+        MinSize=0,
+        MaxSize=20,
+        DesiredCapacity=5,
+        VPCZoneIdentifier=mocked_networking["subnet1"],
+        NewInstancesProtectedFromScaleIn=True,
+    )
+
+    response = client.describe_auto_scaling_groups(AutoScalingGroupNames=["test_asg"])
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+    group = response["AutoScalingGroups"][0]
+    for instance in group["Instances"]:
+        volumes = ec2_client.describe_volumes(
+            Filters=[
+                {"Name": "attachment.instance-id", "Values": [instance["InstanceId"]]}
+            ]
+        )["Volumes"]
+        # The standard root volume
+        assert volumes[0]["VolumeType"] == "gp2"
+        assert volumes[0]["Size"] == 8
+        # Our Ebs-volume
+        assert volumes[1]["VolumeType"] == "gp3"
+        assert volumes[1]["Size"] == 20
+
+
+@mock_aws
 def test_describe_autoscaling_instances_launch_config():
     mocked_networking = setup_networking()
     client = boto3.client("autoscaling", region_name="us-east-1")
@@ -447,8 +488,7 @@ def test_describe_autoscaling_instances_launch_config():
         assert instance["InstanceType"] == "t2.micro"
 
 
-@mock_autoscaling
-@mock_ec2
+@mock_aws
 def test_describe_autoscaling_instances_launch_template():
     mocked_networking = setup_networking()
     ec2_client = boto3.client("ec2", region_name="us-east-1")
@@ -483,7 +523,7 @@ def test_describe_autoscaling_instances_launch_template():
         assert instance["InstanceType"] == "t2.micro"
 
 
-@mock_autoscaling
+@mock_aws
 def test_describe_autoscaling_instances_instanceid_filter():
     mocked_networking = setup_networking()
     client = boto3.client("autoscaling", region_name="us-east-1")
@@ -518,7 +558,7 @@ def test_describe_autoscaling_instances_instanceid_filter():
         assert instance["ProtectedFromScaleIn"] is True
 
 
-@mock_autoscaling
+@mock_aws
 def test_update_autoscaling_group_launch_config():
     mocked_networking = setup_networking()
     client = boto3.client("autoscaling", region_name="us-east-1")
@@ -558,8 +598,7 @@ def test_update_autoscaling_group_launch_config():
     assert group["NewInstancesProtectedFromScaleIn"] is False
 
 
-@mock_autoscaling
-@mock_ec2
+@mock_aws
 def test_update_autoscaling_group_launch_template():
     mocked_networking = setup_networking()
     ec2_client = boto3.client("ec2", region_name="us-east-1")
@@ -610,7 +649,7 @@ def test_update_autoscaling_group_launch_template():
     assert group["NewInstancesProtectedFromScaleIn"] is False
 
 
-@mock_autoscaling
+@mock_aws
 def test_update_autoscaling_group_min_size_desired_capacity_change():
     mocked_networking = setup_networking()
     client = boto3.client("autoscaling", region_name="us-east-1")
@@ -636,7 +675,7 @@ def test_update_autoscaling_group_min_size_desired_capacity_change():
     assert len(group["Instances"]) == 5
 
 
-@mock_autoscaling
+@mock_aws
 def test_update_autoscaling_group_max_size_desired_capacity_change():
     mocked_networking = setup_networking()
     client = boto3.client("autoscaling", region_name="us-east-1")
@@ -662,7 +701,23 @@ def test_update_autoscaling_group_max_size_desired_capacity_change():
     assert len(group["Instances"]) == 5
 
 
-@mock_autoscaling
+@aws_verified
+@pytest.mark.aws_verified
+def test_update_unknown_group():
+    client = boto3.client("autoscaling", region_name="us-east-1")
+    with pytest.raises(ClientError) as exc:
+        client.update_auto_scaling_group(
+            AutoScalingGroupName="fake-asg",
+            MinSize=2,
+            MaxSize=2,
+            DesiredCapacity=2,
+        )
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ValidationError"
+    assert err["Message"] == "AutoScalingGroup name not found - null"
+
+
+@mock_aws
 def test_autoscaling_describe_policies():
     mocked_networking = setup_networking()
     client = boto3.client("autoscaling", region_name="us-east-1")
@@ -737,8 +792,7 @@ def test_autoscaling_describe_policies():
     assert "TargetTrackingConfiguration" not in policy
 
 
-@mock_autoscaling
-@mock_ec2
+@mock_aws
 def test_create_autoscaling_policy_with_policytype__targettrackingscaling():
     mocked_networking = setup_networking(region_name="us-west-1")
     client = boto3.client("autoscaling", region_name="us-west-1")
@@ -843,8 +897,7 @@ def test_create_autoscaling_policy_with_policytype__targettrackingscaling():
     assert "Cooldown" not in policy
 
 
-@mock_autoscaling
-@mock_ec2
+@mock_aws
 def test_create_autoscaling_policy_with_policytype__stepscaling():
     mocked_networking = setup_networking(region_name="eu-west-1")
     client = boto3.client("autoscaling", region_name="eu-west-1")
@@ -897,8 +950,7 @@ def test_create_autoscaling_policy_with_policytype__stepscaling():
     assert "Cooldown" not in policy
 
 
-@mock_autoscaling
-@mock_ec2
+@mock_aws
 def test_create_autoscaling_policy_with_predictive_scaling_config():
     mocked_networking = setup_networking(region_name="eu-west-1")
     client = boto3.client("autoscaling", region_name="eu-west-1")
@@ -936,8 +988,7 @@ def test_create_autoscaling_policy_with_predictive_scaling_config():
     }
 
 
-@mock_autoscaling
-@mock_ec2
+@mock_aws
 @pytest.mark.parametrize("include_instances_distribution", [True, False])
 def test_create_auto_scaling_group_with_mixed_instances_policy(
     include_instances_distribution,
@@ -996,8 +1047,7 @@ def test_create_auto_scaling_group_with_mixed_instances_policy(
         }
 
 
-@mock_autoscaling
-@mock_ec2
+@mock_aws
 def test_create_auto_scaling_group_with_mixed_instances_policy_overrides():
     mocked_networking = setup_networking(region_name="eu-west-1")
     client = boto3.client("autoscaling", region_name="eu-west-1")
@@ -1049,7 +1099,7 @@ def test_create_auto_scaling_group_with_mixed_instances_policy_overrides():
     }
 
 
-@mock_autoscaling
+@mock_aws
 def test_set_instance_protection():
     mocked_networking = setup_networking()
     client = boto3.client("autoscaling", region_name="us-east-1")
@@ -1086,7 +1136,7 @@ def test_set_instance_protection():
         assert instance["ProtectedFromScaleIn"] is (instance["InstanceId"] in protected)
 
 
-@mock_autoscaling
+@mock_aws
 def test_set_desired_capacity_up():
     mocked_networking = setup_networking()
     client = boto3.client("autoscaling", region_name="us-east-1")
@@ -1114,7 +1164,7 @@ def test_set_desired_capacity_up():
         assert instance["ProtectedFromScaleIn"] is True
 
 
-@mock_autoscaling
+@mock_aws
 def test_set_desired_capacity_down():
     mocked_networking = setup_networking()
     client = boto3.client("autoscaling", region_name="us-east-1")
@@ -1157,8 +1207,7 @@ def test_set_desired_capacity_down():
         assert x not in instance_ids  # only unprotected killed
 
 
-@mock_autoscaling
-@mock_ec2
+@mock_aws
 def test_terminate_instance_via_ec2_in_autoscaling_group():
     mocked_networking = setup_networking()
     client = boto3.client("autoscaling", region_name="us-east-1")
@@ -1192,8 +1241,7 @@ def test_terminate_instance_via_ec2_in_autoscaling_group():
     assert replaced_instance_id != original_instance_id
 
 
-@mock_ec2
-@mock_autoscaling
+@mock_aws
 def test_attach_instances():
     asg_client = boto3.client("autoscaling", region_name="us-east-1")
     ec2_client = boto3.client("ec2", region_name="us-east-1")
@@ -1233,7 +1281,7 @@ def test_attach_instances():
         assert instance["InstanceType"] == "c4.2xlarge"
 
 
-@mock_autoscaling
+@mock_aws
 def test_autoscaling_lifecyclehook():
     mocked_networking = setup_networking()
     client = boto3.client("autoscaling", region_name="us-east-1")
@@ -1277,7 +1325,7 @@ def test_autoscaling_lifecyclehook():
 
 
 @pytest.mark.parametrize("original,new", [(2, 1), (2, 3), (1, 5), (1, 1)])
-@mock_autoscaling
+@mock_aws
 def test_set_desired_capacity_without_protection(original, new):
     mocked_networking = setup_networking()
     client = boto3.client("autoscaling", region_name="us-east-1")
@@ -1312,8 +1360,7 @@ def test_set_desired_capacity_without_protection(original, new):
     assert len(instances) == new
 
 
-@mock_autoscaling
-@mock_ec2
+@mock_aws
 def test_create_template_with_block_device():
     ec2_client = boto3.client("ec2", region_name="ap-southeast-2")
     ec2_client.create_launch_template(
@@ -1345,3 +1392,28 @@ def test_create_template_with_block_device():
     # Our Ebs-volume
     assert volumes[1]["VolumeType"] == "gp3"
     assert volumes[1]["Size"] == 20
+
+
+@mock_aws
+def test_sets_created_time():
+    mocked_networking = setup_networking()
+    conn = boto3.client("autoscaling", region_name="us-east-1")
+    conn.create_launch_configuration(
+        LaunchConfigurationName="TestLC",
+        ImageId=EXAMPLE_AMI_ID,
+        InstanceType="t2.medium",
+    )
+
+    conn.create_auto_scaling_group(
+        AutoScalingGroupName="TestGroup1",
+        MinSize=1,
+        MaxSize=2,
+        LaunchConfigurationName="TestLC",
+        VPCZoneIdentifier=mocked_networking["subnet1"],
+    )
+
+    asgs = conn.describe_auto_scaling_groups()["AutoScalingGroups"]
+    assert len(asgs) == 1
+    assert asgs[0]["CreatedTime"].strftime("%Y %m %d") == datetime.now().strftime(
+        "%Y %m %d"
+    )
