@@ -1,28 +1,36 @@
 import json
+import sys
 from typing import Any, Dict, Optional
+from unittest import SkipTest
 from uuid import uuid4
 
 import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_ec2, mock_elbv2, mock_iam, mock_rds, mock_s3, mock_ssm, mock_sts
+from moto import mock_aws
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from moto.core import set_initial_no_auth_action_count
+from moto.utilities.distutils_version import LooseVersion
+
+boto3_version = sys.modules["botocore"].__version__
 
 
-@mock_iam
+@mock_aws
 def create_user_with_access_key(user_name: str = "test-user") -> Dict[str, str]:
     client = boto3.client("iam", region_name="us-east-1")
     client.create_user(UserName=user_name)
     return client.create_access_key(UserName=user_name)["AccessKey"]
 
 
-@mock_iam
+@mock_aws
 def create_user_with_access_key_and_inline_policy(  # type: ignore[misc]
-    user_name: str, policy_document: Dict[str, Any], policy_name: str = "policy1"
+    user_name: str,
+    policy_document: Dict[str, Any],
+    policy_name: str = "policy1",
+    region_name: str = "us-east-1",
 ) -> Dict[str, str]:
-    client = boto3.client("iam", region_name="us-east-1")
+    client = boto3.client("iam", region_name=region_name)
     client.create_user(UserName=user_name)
     client.put_user_policy(
         UserName=user_name,
@@ -32,7 +40,7 @@ def create_user_with_access_key_and_inline_policy(  # type: ignore[misc]
     return client.create_access_key(UserName=user_name)["AccessKey"]
 
 
-@mock_iam
+@mock_aws
 def create_user_with_access_key_and_attached_policy(  # type: ignore[misc]
     user_name: str, policy_document: Dict[str, Any], policy_name: str = "policy1"
 ) -> Dict[str, str]:
@@ -45,7 +53,7 @@ def create_user_with_access_key_and_attached_policy(  # type: ignore[misc]
     return client.create_access_key(UserName=user_name)["AccessKey"]
 
 
-@mock_iam
+@mock_aws
 def create_user_with_access_key_and_multiple_policies(  # type: ignore[misc]
     user_name: str,
     inline_policy_document: Dict[str, Any],
@@ -126,8 +134,7 @@ def create_group_with_multiple_policies_and_add_user(
     client.add_user_to_group(GroupName=group_name, UserName=user_name)
 
 
-@mock_iam
-@mock_sts
+@mock_aws
 def create_role_with_attached_policy_and_assume_it(  # type: ignore[misc]
     role_name: str,
     trust_policy_document: Dict[str, Any],
@@ -149,8 +156,7 @@ def create_role_with_attached_policy_and_assume_it(  # type: ignore[misc]
     ]
 
 
-@mock_iam
-@mock_sts
+@mock_aws
 def create_role_with_inline_policy_and_assume_it(  # type: ignore[misc]
     role_name: str,
     trust_policy_document: Dict[str, Any],
@@ -173,8 +179,36 @@ def create_role_with_inline_policy_and_assume_it(  # type: ignore[misc]
     ]
 
 
+@mock_aws
+def create_role(  # type: ignore[misc]
+    role_name: str,
+    trust_policy_document: Dict[str, Any],
+) -> None:
+    iam_client = boto3.client("iam", region_name="us-east-1")
+    iam_client.create_role(
+        RoleName=role_name, AssumeRolePolicyDocument=json.dumps(trust_policy_document)
+    )
+
+
+@mock_aws
+def create_role_with_attached_policy(  # type: ignore[misc]
+    role_name: str,
+    trust_policy_document: Dict[str, Any],
+    policy_document: Dict[str, Any],
+    policy_name: str = "policy1",
+) -> None:
+    iam_client = boto3.client("iam", region_name="us-east-1")
+    create_role(role_name, trust_policy_document)
+
+    iam_client.put_role_policy(
+        RoleName=role_name,
+        PolicyName=policy_name,
+        PolicyDocument=json.dumps(policy_document),
+    )
+
+
 @set_initial_no_auth_action_count(0)
-@mock_iam
+@mock_aws
 def test_invalid_client_token_id() -> None:
     client = boto3.client(
         "iam",
@@ -191,8 +225,10 @@ def test_invalid_client_token_id() -> None:
 
 
 @set_initial_no_auth_action_count(0)
-@mock_ec2
+@mock_aws
 def test_auth_failure() -> None:
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Error handling is different in newer versions")
     client = boto3.client(
         "ec2",
         region_name="us-east-1",
@@ -210,7 +246,7 @@ def test_auth_failure() -> None:
 
 
 @set_initial_no_auth_action_count(2)
-@mock_iam
+@mock_aws
 def test_signature_does_not_match() -> None:
     access_key = create_user_with_access_key()
     client = boto3.client(
@@ -230,8 +266,10 @@ def test_signature_does_not_match() -> None:
 
 
 @set_initial_no_auth_action_count(2)
-@mock_ec2
+@mock_aws
 def test_auth_failure_with_valid_access_key_id() -> None:
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Error handling is different in newer versions")
     access_key = create_user_with_access_key()
     client = boto3.client(
         "ec2",
@@ -250,8 +288,10 @@ def test_auth_failure_with_valid_access_key_id() -> None:
 
 
 @set_initial_no_auth_action_count(2)
-@mock_ec2
+@mock_aws
 def test_access_denied_with_no_policy() -> None:
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Error handling is different in newer versions")
     user_name = "test-user"
     access_key = create_user_with_access_key(user_name)
     client = boto3.client(
@@ -271,8 +311,10 @@ def test_access_denied_with_no_policy() -> None:
 
 
 @set_initial_no_auth_action_count(3)
-@mock_ec2
+@mock_aws
 def test_access_denied_with_not_allowing_policy() -> None:
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Error handling is different in newer versions")
     user_name = "test-user"
     inline_policy_document = {
         "Version": "2012-10-17",
@@ -298,7 +340,7 @@ def test_access_denied_with_not_allowing_policy() -> None:
 
 
 @set_initial_no_auth_action_count(3)
-@mock_sts
+@mock_aws
 def test_access_denied_explicitly_on_specific_resource() -> None:
     user_name = "test-user"
     forbidden_role_arn = f"arn:aws:iam::{ACCOUNT_ID}:role/forbidden_explicitly"
@@ -339,8 +381,10 @@ def test_access_denied_explicitly_on_specific_resource() -> None:
 
 
 @set_initial_no_auth_action_count(3)
-@mock_ec2
+@mock_aws
 def test_access_denied_for_run_instances() -> None:
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Error handling is different in newer versions")
     # https://github.com/getmoto/moto/issues/2774
     # The run-instances method was broken between botocore versions 1.15.8 and 1.15.12
     # This was due to the inclusion of '"idempotencyToken":true' in the response, somehow altering the signature and breaking the authentication
@@ -372,8 +416,10 @@ def test_access_denied_for_run_instances() -> None:
 
 
 @set_initial_no_auth_action_count(3)
-@mock_ec2
+@mock_aws
 def test_access_denied_with_denying_policy() -> None:
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Error handling is different in newer versions")
     user_name = "test-user"
     inline_policy_document = {
         "Version": "2012-10-17",
@@ -402,7 +448,7 @@ def test_access_denied_with_denying_policy() -> None:
 
 
 @set_initial_no_auth_action_count(3)
-@mock_sts
+@mock_aws
 def test_get_caller_identity_allowed_with_denying_policy() -> None:
     user_name = "test-user"
     inline_policy_document = {
@@ -427,7 +473,7 @@ def test_get_caller_identity_allowed_with_denying_policy() -> None:
 
 
 @set_initial_no_auth_action_count(3)
-@mock_ec2
+@mock_aws
 def test_allowed_with_wildcard_action() -> None:
     user_name = "test-user"
     inline_policy_document = {
@@ -447,7 +493,7 @@ def test_allowed_with_wildcard_action() -> None:
 
 
 @set_initial_no_auth_action_count(4)
-@mock_iam
+@mock_aws
 def test_allowed_with_explicit_action_in_attached_policy() -> None:
     user_name = "test-user"
     attached_policy_document = {
@@ -467,8 +513,7 @@ def test_allowed_with_explicit_action_in_attached_policy() -> None:
 
 
 @set_initial_no_auth_action_count(8)
-@mock_s3
-@mock_iam
+@mock_aws
 def test_s3_access_denied_with_denying_attached_group_policy() -> None:
     user_name = "test-user"
     attached_policy_document = {
@@ -501,8 +546,7 @@ def test_s3_access_denied_with_denying_attached_group_policy() -> None:
 
 
 @set_initial_no_auth_action_count(6)
-@mock_s3
-@mock_iam
+@mock_aws
 def test_s3_access_denied_with_denying_inline_group_policy() -> None:
     user_name = "test-user"
     bucket_name = "test-bucket"
@@ -535,9 +579,10 @@ def test_s3_access_denied_with_denying_inline_group_policy() -> None:
 
 
 @set_initial_no_auth_action_count(10)
-@mock_iam
-@mock_ec2
+@mock_aws
 def test_access_denied_with_many_irrelevant_policies() -> None:
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Error handling is different in newer versions")
     user_name = "test-user"
     inline_policy_document = {
         "Version": "2012-10-17",
@@ -584,10 +629,7 @@ def test_access_denied_with_many_irrelevant_policies() -> None:
 
 
 @set_initial_no_auth_action_count(4)
-@mock_iam
-@mock_sts
-@mock_ec2
-@mock_elbv2
+@mock_aws
 def test_allowed_with_temporary_credentials() -> None:
     role_name = "test-role"
     trust_policy_document = {
@@ -636,9 +678,7 @@ def test_allowed_with_temporary_credentials() -> None:
 
 
 @set_initial_no_auth_action_count(3)
-@mock_iam
-@mock_sts
-@mock_rds
+@mock_aws
 def test_access_denied_with_temporary_credentials() -> None:
     role_name = "test-role"
     session_name = "test-session"
@@ -681,7 +721,7 @@ def test_access_denied_with_temporary_credentials() -> None:
 
 
 @set_initial_no_auth_action_count(3)
-@mock_iam
+@mock_aws
 def test_get_user_from_credentials() -> None:
     user_name = "new-test-user"
     inline_policy_document = {
@@ -701,7 +741,7 @@ def test_get_user_from_credentials() -> None:
 
 
 @set_initial_no_auth_action_count(0)
-@mock_s3
+@mock_aws
 def test_s3_invalid_access_key_id() -> None:
     client = boto3.client(
         "s3",
@@ -720,8 +760,7 @@ def test_s3_invalid_access_key_id() -> None:
 
 
 @set_initial_no_auth_action_count(3)
-@mock_s3
-@mock_iam
+@mock_aws
 def test_s3_signature_does_not_match() -> None:
     bucket_name = "test-bucket"
     access_key = create_user_with_access_key()
@@ -743,8 +782,7 @@ def test_s3_signature_does_not_match() -> None:
 
 
 @set_initial_no_auth_action_count(7)
-@mock_s3
-@mock_iam
+@mock_aws
 def test_s3_access_denied_not_action() -> None:
     user_name = "test-user"
     bucket_name = "test-bucket"
@@ -777,9 +815,7 @@ def test_s3_access_denied_not_action() -> None:
 
 
 @set_initial_no_auth_action_count(4)
-@mock_iam
-@mock_sts
-@mock_s3
+@mock_aws
 def test_s3_invalid_token_with_temporary_credentials() -> None:
     role_name = "test-role"
     session_name = "test-session"
@@ -816,9 +852,11 @@ def test_s3_invalid_token_with_temporary_credentials() -> None:
 
 
 @set_initial_no_auth_action_count(3)
-@mock_s3
-@mock_iam
-def test_allow_bucket_access_using_resource_arn() -> None:
+@mock_aws
+@pytest.mark.parametrize(
+    "region,partition", [("us-west-2", "aws"), ("cn-north-1", "aws-cn")]
+)
+def test_allow_bucket_access_using_resource_arn(region: str, partition: str) -> None:
     user_name = "test-user"
     policy_doc = {
         "Version": "2012-10-17",
@@ -826,21 +864,25 @@ def test_allow_bucket_access_using_resource_arn() -> None:
             {
                 "Action": ["s3:*"],
                 "Effect": "Allow",
-                "Resource": "arn:aws:s3:::my_bucket",
+                "Resource": f"arn:{partition}:s3:::my_bucket",
                 "Sid": "BucketLevelGrants",
             },
         ],
     }
-    access_key = create_user_with_access_key_and_inline_policy(user_name, policy_doc)
+    access_key = create_user_with_access_key_and_inline_policy(
+        user_name, policy_doc, region_name=region
+    )
 
     s3_client = boto3.client(
         "s3",
-        region_name="us-east-1",
+        region_name=region,
         aws_access_key_id=access_key["AccessKeyId"],
         aws_secret_access_key=access_key["SecretAccessKey"],
     )
 
-    s3_client.create_bucket(Bucket="my_bucket")
+    s3_client.create_bucket(
+        Bucket="my_bucket", CreateBucketConfiguration={"LocationConstraint": region}
+    )
     with pytest.raises(ClientError):
         s3_client.create_bucket(Bucket="my_bucket2")
 
@@ -850,8 +892,7 @@ def test_allow_bucket_access_using_resource_arn() -> None:
 
 
 @set_initial_no_auth_action_count(3)
-@mock_s3
-@mock_iam
+@mock_aws
 def test_allow_key_access_using_resource_arn() -> None:
     user_name = "test-user"
     policy_doc = {
@@ -881,8 +922,7 @@ def test_allow_key_access_using_resource_arn() -> None:
 
 
 @set_initial_no_auth_action_count(3)
-@mock_ssm
-@mock_iam
+@mock_aws
 def test_ssm_service() -> None:
     user_name = "test-user"
     policy_doc = {
@@ -899,3 +939,287 @@ def test_ssm_service() -> None:
     )
 
     ssmc.put_parameter(Name="test", Value="value", Type="String")
+
+
+@set_initial_no_auth_action_count(4)
+@mock_aws
+def test_sts_assume_role_with_external_id() -> None:
+    user_name = "test-user"
+    role_name = "test-role"
+
+    user_policy_doc = {
+        "Version": "2012-10-17",
+        "Statement": [
+            {
+                "Effect": "Allow",
+                "Action": "sts:AssumeRole",
+                "Resource": f"arn:aws:iam::{ACCOUNT_ID}:role/{role_name}",
+            }
+        ],
+    }
+
+    user_access_keys = create_user_with_access_key_and_inline_policy(
+        user_name, user_policy_doc
+    )
+
+    external_id = "test-external-id"
+    incorrect_external_id = "test-incorrect-external-id"
+    trust_policy_document = {
+        "Version": "2012-10-17",
+        "Statement": [
+            {
+                "Effect": "Allow",
+                "Action": "sts:AssumeRole",
+                "Principal": {
+                    "AWS": f"arn:aws:iam::{ACCOUNT_ID}:user/{user_name}",
+                },
+                "Condition": {
+                    "StringEquals": {
+                        "sts:ExternalId": external_id,
+                    },
+                },
+            },
+        ],
+    }
+    create_role(role_name, trust_policy_document)
+
+    client = boto3.client(
+        "sts",
+        region_name="us-east-1",
+        aws_access_key_id=user_access_keys["AccessKeyId"],
+        aws_secret_access_key=user_access_keys["SecretAccessKey"],
+    )
+    with pytest.raises(ClientError) as ex:
+        client.assume_role(
+            RoleArn=f"arn:aws:iam::{ACCOUNT_ID}:role/{role_name}",
+            RoleSessionName="test-session",
+            ExternalId=incorrect_external_id,
+        )
+    assert ex.value.response["Error"]["Code"] == "AccessDenied"
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 403
+    assert (
+        ex.value.response["Error"]["Message"]
+        == f"User: arn:aws:iam::{ACCOUNT_ID}:user/{user_name} is not authorized to perform: sts:AssumeRole"
+    )
+    # Not raising means success
+    client.assume_role(
+        RoleArn=f"arn:aws:iam::{ACCOUNT_ID}:role/{role_name}",
+        RoleSessionName="test-session",
+        ExternalId=external_id,
+    )
+
+
+@set_initial_no_auth_action_count(7)
+@mock_aws
+def test_sts_assume_role_with_principal() -> None:
+    user_name = "test-user"
+    incorrect_user_name = "test-incorrect-user"
+    role_name = "test-role"
+
+    user_policy_doc = {
+        "Version": "2012-10-17",
+        "Statement": [
+            {
+                "Effect": "Allow",
+                "Action": "sts:AssumeRole",
+                "Resource": f"arn:aws:iam::{ACCOUNT_ID}:role/{role_name}",
+            }
+        ],
+    }
+
+    user_access_keys = create_user_with_access_key_and_inline_policy(
+        user_name, user_policy_doc, policy_name="policy-1"
+    )
+    incorrect_user_access_keys = create_user_with_access_key_and_inline_policy(
+        incorrect_user_name, user_policy_doc, policy_name="policy-2"
+    )
+
+    trust_policy_document = {
+        "Version": "2012-10-17",
+        "Statement": [
+            {
+                "Effect": "Allow",
+                "Action": "sts:AssumeRole",
+                "Principal": {
+                    "AWS": f"arn:aws:iam::{ACCOUNT_ID}:user/{user_name}",
+                },
+            },
+        ],
+    }
+    create_role(role_name, trust_policy_document)
+
+    client = boto3.client(
+        "sts",
+        region_name="us-east-1",
+        aws_access_key_id=incorrect_user_access_keys["AccessKeyId"],
+        aws_secret_access_key=incorrect_user_access_keys["SecretAccessKey"],
+    )
+    with pytest.raises(ClientError) as ex:
+        client.assume_role(
+            RoleArn=f"arn:aws:iam::{ACCOUNT_ID}:role/{role_name}",
+            RoleSessionName="test-session",
+        )
+    assert ex.value.response["Error"]["Code"] == "AccessDenied"
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 403
+    assert (
+        ex.value.response["Error"]["Message"]
+        == f"User: arn:aws:iam::{ACCOUNT_ID}:user/{incorrect_user_name} is not authorized to perform: sts:AssumeRole"
+    )
+    # Not raising means success
+    client = boto3.client(
+        "sts",
+        region_name="us-east-1",
+        aws_access_key_id=user_access_keys["AccessKeyId"],
+        aws_secret_access_key=user_access_keys["SecretAccessKey"],
+    )
+    client.assume_role(
+        RoleArn=f"arn:aws:iam::{ACCOUNT_ID}:role/{role_name}",
+        RoleSessionName="test-session",
+    )
+
+
+@set_initial_no_auth_action_count(6)
+@mock_aws
+def test_perform_role_based_action() -> None:
+    user_name = "test-user"
+    role_name = "test-role"
+    incorrect_role_name = "test-incorrect-role"
+
+    user_policy_doc = {
+        "Version": "2012-10-17",
+        "Statement": [
+            {
+                "Effect": "Allow",
+                "Action": "sts:AssumeRole",
+                "Resource": [
+                    f"arn:aws:iam::{ACCOUNT_ID}:role/{role_name}",
+                    f"arn:aws:iam::{ACCOUNT_ID}:role/{incorrect_role_name}",
+                ],
+            }
+        ],
+    }
+
+    user_access_keys = create_user_with_access_key_and_inline_policy(
+        user_name, user_policy_doc
+    )
+
+    trust_policy_document = {
+        "Version": "2012-10-17",
+        "Statement": [
+            {
+                "Effect": "Allow",
+                "Action": "sts:AssumeRole",
+                "Principal": {
+                    "AWS": f"arn:aws:iam::{ACCOUNT_ID}:user/{user_name}",
+                },
+            },
+        ],
+    }
+    attached_policy_name = "test-attached-policy"
+    attached_policy_doc = {
+        "Version": "2012-10-17",
+        "Statement": [
+            {
+                "Effect": "Allow",
+                "Action": "iam:ListRolePolicies",
+                "Resource": f"arn:aws:iam::{ACCOUNT_ID}:role/{role_name}",
+            }
+        ],
+    }
+
+    create_role(incorrect_role_name, trust_policy_document)
+    create_role_with_attached_policy(
+        role_name, trust_policy_document, attached_policy_doc, attached_policy_name
+    )
+
+    client = boto3.client(
+        "sts",
+        region_name="us-east-1",
+        aws_access_key_id=user_access_keys["AccessKeyId"],
+        aws_secret_access_key=user_access_keys["SecretAccessKey"],
+    )
+
+    session_name = "test-session"
+    assumed_role_credentials = client.assume_role(
+        RoleArn=f"arn:aws:iam::{ACCOUNT_ID}:role/{role_name}",
+        RoleSessionName=session_name,
+    )["Credentials"]
+
+    iam_client = boto3.client(
+        "iam",
+        region_name="us-east-1",
+        aws_access_key_id=assumed_role_credentials["AccessKeyId"],
+        aws_secret_access_key=assumed_role_credentials["SecretAccessKey"],
+        aws_session_token=assumed_role_credentials["SessionToken"],
+    )
+
+    with pytest.raises(ClientError) as ex:
+        iam_client.list_role_policies(RoleName=incorrect_role_name)
+    assert ex.value.response["Error"]["Code"] == "AccessDenied"
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 403
+    assert (
+        ex.value.response["Error"]["Message"]
+        == f"User: arn:aws:sts::{ACCOUNT_ID}:assumed-role/{role_name}/{session_name} is not authorized to perform: iam:ListRolePolicies"
+    )
+
+    assert (
+        attached_policy_name
+        in iam_client.list_role_policies(RoleName=role_name)["PolicyNames"]
+    )
+
+
+@set_initial_no_auth_action_count(4)
+@mock_aws
+def test_sts_assume_role_with_external_id_unsupported_operation_should_supress_error() -> (
+    None
+):
+    user_name = "test-user"
+    role_name = "test-role"
+
+    user_policy_doc = {
+        "Version": "2012-10-17",
+        "Statement": [
+            {
+                "Effect": "Allow",
+                "Action": "sts:AssumeRole",
+                "Resource": f"arn:aws:iam::{ACCOUNT_ID}:role/{role_name}",
+            }
+        ],
+    }
+
+    user_access_keys = create_user_with_access_key_and_inline_policy(
+        user_name, user_policy_doc
+    )
+
+    external_id = "test-external-id"
+    trust_policy_document = {
+        "Version": "2012-10-17",
+        "Statement": [
+            {
+                "Effect": "Allow",
+                "Action": "sts:AssumeRole",
+                "Principal": {
+                    "AWS": f"arn:aws:iam::{ACCOUNT_ID}:user/{user_name}",
+                },
+                "Condition": {
+                    "UnsupportedOperation": {
+                        "sts:ExternalId": external_id,
+                    },
+                },
+            },
+        ],
+    }
+    create_role(role_name, trust_policy_document)
+
+    client = boto3.client(
+        "sts",
+        region_name="us-east-1",
+        aws_access_key_id=user_access_keys["AccessKeyId"],
+        aws_secret_access_key=user_access_keys["SecretAccessKey"],
+    )
+    # Not raising means success
+    client.assume_role(
+        RoleArn=f"arn:aws:iam::{ACCOUNT_ID}:role/{role_name}",
+        RoleSessionName="test-session",
+        ExternalId=external_id,
+    )
