@@ -1,10 +1,14 @@
+import sys
 from typing import Any, List
 from unittest import SkipTest
 
 import boto3
 import pytest
 
-from moto import mock_s3, settings
+from moto import mock_aws, settings
+from moto.utilities.distutils_version import LooseVersion
+
+boto3_version = sys.modules["botocore"].__version__
 
 
 @pytest.fixture(scope="function", name="aws_credentials")
@@ -19,9 +23,9 @@ def fixture_aws_credentials(monkeypatch: Any) -> None:  # type: ignore[misc]
 
 
 def test_mock_works_with_client_created_inside(
-    aws_credentials: Any,  # pylint: disable=unused-argument
+    aws_credentials: Any,
 ) -> None:
-    m = mock_s3()
+    m = mock_aws()
     m.start()
     client = boto3.client("s3", region_name="us-east-1")
 
@@ -31,13 +35,13 @@ def test_mock_works_with_client_created_inside(
 
 
 def test_mock_works_with_client_created_outside(
-    aws_credentials: Any,  # pylint: disable=unused-argument
+    aws_credentials: Any,
 ) -> None:
     # Create the boto3 client first
     outside_client = boto3.client("s3", region_name="us-east-1")
 
     # Start the mock afterwards - which does not mock an already created client
-    m = mock_s3()
+    m = mock_aws()
     m.start()
 
     # So remind us to mock this client
@@ -51,13 +55,13 @@ def test_mock_works_with_client_created_outside(
 
 
 def test_mock_works_with_resource_created_outside(
-    aws_credentials: Any,  # pylint: disable=unused-argument
+    aws_credentials: Any,
 ) -> None:
     # Create the boto3 client first
     outside_resource = boto3.resource("s3", region_name="us-east-1")
 
     # Start the mock afterwards - which does not mock an already created resource
-    m = mock_s3()
+    m = mock_aws()
     m.start()
 
     # So remind us to mock this resource
@@ -70,8 +74,10 @@ def test_mock_works_with_resource_created_outside(
 
 
 def test_patch_can_be_called_on_a_mocked_client() -> None:
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Error handling is different in newer versions")
     # start S3 after the mock, ensuring that the client contains our event-handler
-    m = mock_s3()
+    m = mock_aws()
     m.start()
     client = boto3.client("s3", region_name="us-east-1")
 
@@ -80,7 +86,7 @@ def test_patch_can_be_called_on_a_mocked_client() -> None:
     patch_client(client)
     patch_client(client)
 
-    # At this point, our event-handler should only be registered once, by `mock_s3`
+    # At this point, our event-handler should only be registered once, by `mock_aws`
     # `patch_client` should not re-register the event-handler
     test_object = b"test_object_text"
     client.create_bucket(Bucket="buck")
@@ -116,11 +122,13 @@ class ImportantBusinessLogic:
 
 
 def test_mock_works_when_replacing_client(
-    aws_credentials: Any,  # pylint: disable=unused-argument
+    aws_credentials: Any,
 ) -> None:
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Error handling is different in newer versions")
     logic = ImportantBusinessLogic()
 
-    m = mock_s3()
+    m = mock_aws()
     m.start()
 
     # This will fail, as the S3 client was created before the mock was initialized
