@@ -1,5 +1,4 @@
-from moto.dynamodb.models.dynamo_type import DynamoType, Item
-from moto.dynamodb.models.dynamo_type import serializer
+from moto.dynamodb.models.dynamo_type import DynamoType, Item, serializer
 
 
 class TestFindNestedKeys:
@@ -34,17 +33,17 @@ class TestFindNestedKeys:
         assert x == y
 
     def test_find_nothing(self):
-        self._project("", result={})
+        self._project([[""]], result={})
 
     def test_find_unknown_key(self):
-        self._project("unknown", result={})
+        self._project([["unknown"]], result={})
 
     def test_project_single_key_string(self):
-        self._project("simplestring", result={"simplestring": "val"})
+        self._project([["simplestring"]], result={"simplestring": "val"})
 
     def test_project_single_key_dict(self):
         self._project(
-            "nesteddict",
+            [["nesteddict"]],
             result={
                 "nesteddict": {
                     "level21": {"ll31": "val", "ll32": "val"},
@@ -59,31 +58,31 @@ class TestFindNestedKeys:
 
     def test_project_nested_key(self):
         self._project(
-            "nesteddict.level21",
+            [["nesteddict", "level21"]],
             result={"nesteddict": {"level21": {"ll31": "val", "ll32": "val"}}},
         )
 
     def test_project_multi_level_nested_key(self):
         self._project(
-            "nesteddict.level21.ll32",
+            [["nesteddict", "level21", "ll32"]],
             result={"nesteddict": {"level21": {"ll32": "val"}}},
         )
 
     def test_project_nested_key__partial_fix(self):
-        self._project("nesteddict.levelunknown", result={})
+        self._project([["nesteddict", "levelunknown"]], result={})
 
     def test_project_nested_key__partial_fix2(self):
-        self._project("nesteddict.unknown.unknown2", result={})
+        self._project([["nesteddict", "unknown", "unknown2"]], result={})
 
     def test_list_index(self):
         self._project(
-            "rootlist[0]",
+            [["rootlist[0]"]],
             result={"rootlist": [{"ll21": {"ll31": "val", "ll32": "val"}}]},
         )
 
     def test_nested_list_index(self):
         self._project(
-            "nesteddict.nestedlist[1]",
+            [["nesteddict", "nestedlist[1]"]],
             result={
                 "nesteddict": {"nestedlist": [{"ll22": {"ll31": "val", "ll32": "val"}}]}
             },
@@ -91,16 +90,16 @@ class TestFindNestedKeys:
 
     def test_nested_obj_in_list(self):
         self._project(
-            "nesteddict.nestedlist[1].ll22.ll31",
+            [["nesteddict", "nestedlist[1]", "ll22", "ll31"]],
             result={"nesteddict": {"nestedlist": [{"ll22": {"ll31": "val"}}]}},
         )
 
     def test_list_unknown_indexes(self):
-        self._project("nesteddict.nestedlist[25]", result={})
+        self._project([["nesteddict", "nestedlist[25]"]], result={})
 
     def test_multiple_projections(self):
         self._project(
-            "nesteddict.nestedlist[1].ll22,rootlist[0]",
+            [["nesteddict", "nestedlist[1]", "ll22"], ["rootlist[0]"]],
             result={
                 "nesteddict": {
                     "nestedlist": [{"ll22": {"ll31": "val", "ll32": "val"}}]
