@@ -6,11 +6,11 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_ec2, settings
-from tests import EXAMPLE_AMI_ID
+from moto import mock_aws, settings
+from tests import DEFAULT_ACCOUNT_ID, EXAMPLE_AMI_ID
 
 
-@mock_ec2
+@mock_aws
 def test_subnets():
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     client = boto3.client("ec2", region_name="us-east-1")
@@ -34,7 +34,99 @@ def test_subnets():
     assert ex.value.response["Error"]["Code"] == "InvalidSubnetID.NotFound"
 
 
-@mock_ec2
+@mock_aws
+def test_create_default_subnet():
+    client = boto3.client("ec2", region_name="ap-northeast-1")
+
+    default_vpc = client.describe_vpcs(
+        Filters=[{"Name": "is-default", "Values": ["true"]}]
+    )["Vpcs"][0]
+
+    zones = [
+        z["ZoneName"] for z in client.describe_availability_zones()["AvailabilityZones"]
+    ]
+
+    # Ensure moto has default subnets by default
+    subnets = client.describe_subnets(
+        Filters=[{"Name": "default-for-az", "Values": ["true"]}]
+    )["Subnets"]
+    assert len(subnets) == len(zones)
+
+    default_subnets: dict[str, str] = {
+        subnet["AvailabilityZone"]: subnet["SubnetId"] for subnet in subnets
+    }
+
+    # Ensure that attempting to create a default subnet when it already exists raises
+    for zone in zones:
+        with pytest.raises(ClientError) as exc:
+            client.create_default_subnet(AvailabilityZone=zone)
+        assert (
+            exc.value.response["Error"]["Code"]
+            == "DefaultSubnetAlreadyExistsInAvailabilityZone"
+        )
+        assert (
+            exc.value.response["Error"]["Message"]
+            == f"'{default_subnets[zone]}' is already the default subnet in {zone}."
+        )
+
+    # Delete default subnets
+    for subnet in subnets:
+        client.delete_subnet(SubnetId=subnet["SubnetId"])
+    default_subnets.clear()
+
+    expected_cidr_blocks = [
+        "172.31.0.0/20",
+        "172.31.16.0/20",
+        "172.31.32.0/20",
+        "172.31.48.0/20",
+        "172.31.64.0/20",
+        "172.31.80.0/20",
+    ]
+
+    # Ensure default subnets can be created
+    for idx, zone in enumerate(zones):
+        response = client.create_default_subnet(AvailabilityZone=zone)["Subnet"]
+        assert response["OwnerId"] == DEFAULT_ACCOUNT_ID
+        assert response["VpcId"] == default_vpc["VpcId"]
+        assert response["State"] == "available"
+        assert response["CidrBlock"] == expected_cidr_blocks[idx]
+        assert response["AvailabilityZone"] == zone
+        assert response["DefaultForAz"] is True
+        subnet_id = default_subnets[zone] = response["SubnetId"]
+
+        response = client.describe_subnets(SubnetIds=[subnet_id])
+        assert len(response["Subnets"]) == 1
+        assert response["Subnets"][0]["SubnetId"] == subnet_id
+        assert response["Subnets"][0]["VpcId"] == default_vpc["VpcId"]
+        assert response["Subnets"][0]["DefaultForAz"] is True
+        assert response["Subnets"][0]["CidrBlock"] == expected_cidr_blocks[idx]
+        assert response["Subnets"][0]["AvailabilityZone"] == zone
+
+    # Delete default subnets and VPCs
+    for subnet_id in default_subnets.values():
+        client.delete_subnet(SubnetId=subnet_id)
+    client.delete_vpc(VpcId=default_vpc["VpcId"])
+
+    # Ensure attempting to create default subnet when there's no default VPC raises
+    for zone in zones:
+        with pytest.raises(ClientError) as exc:
+            client.create_default_subnet(AvailabilityZone=zone)
+
+        assert exc.value.response["Error"]["Code"] == "DefaultVpcDoesNotExist"
+        assert (
+            exc.value.response["Error"]["Message"]
+            == "No default VPC exists for this account in this region."
+        )
+
+    # Ensure creating a default VPC also creates default subnets
+    client.create_default_vpc()
+    subnets = client.describe_subnets(
+        Filters=[{"Name": "default-for-az", "Values": ["true"]}]
+    )["Subnets"]
+    assert len(subnets) == len(zones)
+
+
+@mock_aws
 def test_subnet_create_vpc_validation():
     ec2 = boto3.resource("ec2", region_name="us-east-1")
 
@@ -45,7 +137,7 @@ def test_subnet_create_vpc_validation():
     assert ex.value.response["Error"]["Code"] == "InvalidVpcID.NotFound"
 
 
-@mock_ec2
+@mock_aws
 def test_subnet_tagging():
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     client = boto3.client("ec2", region_name="us-east-1")
@@ -65,7 +157,7 @@ def test_subnet_tagging():
     assert subnet["Tags"] == [{"Key": "a key", "Value": "some value"}]
 
 
-@mock_ec2
+@mock_aws
 def test_subnet_should_have_proper_availability_zone_set():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     vpcA = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -75,7 +167,7 @@ def test_subnet_should_have_proper_availability_zone_set():
     assert subnetA.availability_zone == "us-west-1b"
 
 
-@mock_ec2
+@mock_aws
 def test_availability_zone_in_create_subnet():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
 
@@ -87,7 +179,7 @@ def test_availability_zone_in_create_subnet():
     assert subnet.availability_zone_id == "use1-az6"
 
 
-@mock_ec2
+@mock_aws
 def test_default_subnet():
     if settings.TEST_SERVER_MODE:
         raise SkipTest("ServerMode will have conflicting CidrBlocks")
@@ -105,7 +197,7 @@ def test_default_subnet():
     assert subnet.map_public_ip_on_launch is False
 
 
-@mock_ec2
+@mock_aws
 def test_non_default_subnet():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
 
@@ -121,7 +213,7 @@ def test_non_default_subnet():
     assert subnet.map_public_ip_on_launch is False
 
 
-@mock_ec2
+@mock_aws
 def test_modify_subnet_attribute_public_ip_on_launch():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -154,7 +246,7 @@ def test_modify_subnet_attribute_public_ip_on_launch():
     assert subnet.map_public_ip_on_launch is True
 
 
-@mock_ec2
+@mock_aws
 def test_modify_subnet_attribute_assign_ipv6_address_on_creation():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -188,7 +280,7 @@ def test_modify_subnet_attribute_assign_ipv6_address_on_creation():
     assert subnet.assign_ipv6_address_on_creation is True
 
 
-@mock_ec2
+@mock_aws
 def test_modify_subnet_attribute_validation():
     # TODO: implement some actual logic
     ec2 = boto3.resource("ec2", region_name="us-west-1")
@@ -198,7 +290,7 @@ def test_modify_subnet_attribute_validation():
     )
 
 
-@mock_ec2
+@mock_aws
 def test_subnet_get_by_id():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -229,7 +321,7 @@ def test_subnet_get_by_id():
     assert ex.value.response["Error"]["Code"] == "InvalidSubnetID.NotFound"
 
 
-@mock_ec2
+@mock_aws
 def test_get_subnets_filtering():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -330,8 +422,18 @@ def test_get_subnets_filtering():
         with pytest.raises(NotImplementedError):
             client.describe_subnets(Filters=filters)
 
+    # Filter without a Value.
+    subnets_with_invalid_filter = client.describe_subnets(Filters=[{"Name": "vpc-id"}])[
+        "Subnets"
+    ]
+    assert len(subnets_with_invalid_filter) == 0
+    subnets_with_invalid_filter = client.describe_subnets(
+        Filters=[{"Name": "vpc-id", "Values": []}]
+    )["Subnets"]
+    assert len(subnets_with_invalid_filter) == 0
 
-@mock_ec2
+
+@mock_aws
 def test_create_subnet_response_fields():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -360,7 +462,7 @@ def test_create_subnet_response_fields():
     assert subnet["Ipv6CidrBlockAssociationSet"] == []
 
 
-@mock_ec2
+@mock_aws
 def test_describe_subnet_response_fields():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -393,7 +495,7 @@ def test_describe_subnet_response_fields():
     assert subnet["Ipv6CidrBlockAssociationSet"] == []
 
 
-@mock_ec2
+@mock_aws
 def test_create_subnet_with_invalid_availability_zone():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -413,7 +515,7 @@ def test_create_subnet_with_invalid_availability_zone():
     )
 
 
-@mock_ec2
+@mock_aws
 def test_create_subnet_with_invalid_cidr_range():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
 
@@ -430,7 +532,7 @@ def test_create_subnet_with_invalid_cidr_range():
     )
 
 
-@mock_ec2
+@mock_aws
 def test_create_subnet_with_invalid_cidr_range_multiple_vpc_cidr_blocks():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
 
@@ -448,7 +550,7 @@ def test_create_subnet_with_invalid_cidr_range_multiple_vpc_cidr_blocks():
     )
 
 
-@mock_ec2
+@mock_aws
 def test_create_subnet_with_invalid_cidr_block_parameter():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
 
@@ -465,7 +567,7 @@ def test_create_subnet_with_invalid_cidr_block_parameter():
     )
 
 
-@mock_ec2
+@mock_aws
 def test_create_subnets_with_multiple_vpc_cidr_blocks():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -505,7 +607,7 @@ def test_create_subnets_with_multiple_vpc_cidr_blocks():
         assert subnet["AssignIpv6AddressOnCreation"] is False
 
 
-@mock_ec2
+@mock_aws
 def test_create_subnets_with_overlapping_cidr_blocks():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
 
@@ -523,7 +625,7 @@ def test_create_subnets_with_overlapping_cidr_blocks():
     )
 
 
-@mock_ec2
+@mock_aws
 def test_create_subnet_with_tags():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     vpc = ec2.create_vpc(CidrBlock="172.31.0.0/16")
@@ -545,7 +647,7 @@ def test_create_subnet_with_tags():
     assert subnet.tags == [{"Key": "name", "Value": "some-vpc"}]
 
 
-@mock_ec2
+@mock_aws
 def test_available_ip_addresses_in_subnet():
     if settings.TEST_SERVER_MODE:
         raise SkipTest(
@@ -574,7 +676,7 @@ def test_available_ip_addresses_in_subnet():
         validate_subnet_details(client, vpc, cidr, expected_count)
 
 
-@mock_ec2
+@mock_aws
 def test_available_ip_addresses_in_subnet_with_enis():
     if settings.TEST_SERVER_MODE:
         raise SkipTest(
@@ -668,7 +770,7 @@ def validate_subnet_details_after_creating_eni(
     client.delete_subnet(SubnetId=subnet["SubnetId"])
 
 
-@mock_ec2
+@mock_aws
 def test_run_instances_should_attach_to_default_subnet():
     # https://github.com/getmoto/moto/issues/2877
     ec2 = boto3.resource("ec2", region_name="sa-east-1")
@@ -703,7 +805,7 @@ def test_run_instances_should_attach_to_default_subnet():
         )
 
 
-@mock_ec2
+@mock_aws
 def test_describe_subnets_by_vpc_id():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -742,7 +844,7 @@ def test_describe_subnets_by_vpc_id():
     assert len(subnets) == 0
 
 
-@mock_ec2
+@mock_aws
 def test_describe_subnets_by_state():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -759,7 +861,7 @@ def test_describe_subnets_by_state():
         assert subnet["State"] == "available"
 
 
-@mock_ec2
+@mock_aws
 def test_associate_subnet_cidr_block():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -789,7 +891,7 @@ def test_associate_subnet_cidr_block():
     assert association_set[0]["Ipv6CidrBlock"] == "1080::1:200C:417A/112"
 
 
-@mock_ec2
+@mock_aws
 def test_disassociate_subnet_cidr_block():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -818,7 +920,7 @@ def test_disassociate_subnet_cidr_block():
     assert association_set[0]["Ipv6CidrBlock"] == "1080::1:200C:417A/111"
 
 
-@mock_ec2
+@mock_aws
 def test_describe_subnets_dryrun():
     client = boto3.client("ec2", region_name="us-east-1")
 
