@@ -1,10 +1,9 @@
 import json
-import requests
-import sure  # noqa # pylint: disable=unused-import
+from unittest import SkipTest
 
+import requests
 
 from moto import settings
-from unittest import SkipTest
 
 
 def test_set_transition():
@@ -18,13 +17,13 @@ def test_set_transition():
         "http://localhost:5000/moto-api/state-manager/set-transition",
         data=json.dumps(post_body),
     )
-    resp.status_code.should.equal(201)
+    assert resp.status_code == 201
 
     resp = requests.get(
         "http://localhost:5000/moto-api/state-manager/get-transition?model_name=test_model0"
     )
-    resp.status_code.should.equal(200)
-    json.loads(resp.content).should.equal({"progression": "waiter", "wait_times": 3})
+    assert resp.status_code == 200
+    assert json.loads(resp.content) == {"progression": "waiter", "wait_times": 3}
 
 
 def test_unset_transition():
@@ -48,8 +47,8 @@ def test_unset_transition():
     resp = requests.get(
         "http://localhost:5000/moto-api/state-manager/get-transition?model_name=test::model1"
     )
-    resp.status_code.should.equal(200)
-    json.loads(resp.content).should.equal({"progression": "immediate"})
+    assert resp.status_code == 200
+    assert json.loads(resp.content) == {"progression": "immediate"}
 
 
 def test_get_default_transition():
@@ -59,5 +58,5 @@ def test_get_default_transition():
     resp = requests.get(
         "http://localhost:5000/moto-api/state-manager/get-transition?model_name=unknown"
     )
-    resp.status_code.should.equal(200)
-    json.loads(resp.content).should.equal({"progression": "immediate"})
+    assert resp.status_code == 200
+    assert json.loads(resp.content) == {"progression": "immediate"}
