@@ -1,6 +1,6 @@
 from urllib.parse import urlencode
+
 import moto.server as server
-import sure  # noqa # pylint: disable=unused-import
 
 
 def test_list_databases():
@@ -9,29 +9,27 @@ def test_list_databases():
 
     res = test_client.get("/?Action=DescribeDBInstances")
 
-    res.data.decode("utf-8").should.contain("<DescribeDBInstancesResult>")
+    assert "<DescribeDBInstancesResult>" in res.data.decode("utf-8")
 
 
 def test_create_db_instance():
     backend = server.create_backend_app("rds")
     test_client = backend.test_client()
-
     params = {
         "Action": "CreateDBInstance",
         "DBInstanceIdentifier": "hi",
         "DBInstanceClass": "db.m4.large",
-        "Engine": "aurora",
+        "Engine": "postgres",
         "StorageType": "standard",
-        "Port": 3306,
+        "Port": 5432,
     }
     qs = urlencode(params)
     resp = test_client.post(f"/?{qs}")
-
     response = resp.data.decode("utf-8")
-    response.shouldnt.contain("<DBClusterIdentifier>")
-    response.should.contain("<DBInstanceIdentifier>hi</DBInstanceIdentifier")
+    assert "<DBClusterIdentifier>" not in response
+    assert "<DBInstanceIdentifier>hi</DBInstanceIdentifier" in response
     # We do not pass these values - they should default to false
-    response.should.contain("<MultiAZ>false</MultiAZ>")
-    response.should.contain(
+    assert "<MultiAZ>false</MultiAZ>" in response
+    assert (
         "<IAMDatabaseAuthenticationEnabled>false</IAMDatabaseAuthenticationEnabled>"
-    )
+    ) in response
