@@ -4,7 +4,7 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_sagemaker
+from moto import mock_aws
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 TEST_REGION_NAME = "us-east-1"
@@ -28,7 +28,7 @@ FAKE_INSTANCE_TYPE_PARAM = "ml.t2.medium"
 
 @pytest.fixture(name="client")
 def fixture_sagemaker_client():
-    with mock_sagemaker():
+    with mock_aws():
         yield boto3.client("sagemaker", region_name=TEST_REGION_NAME)
 
 
@@ -39,7 +39,7 @@ def _get_notebook_instance_arn(notebook_name):
 def _get_notebook_instance_lifecycle_arn(lifecycle_name):
     return (
         f"arn:aws:sagemaker:{TEST_REGION_NAME}:{ACCOUNT_ID}"
-        f":notebook-instance-lifecycle-configuration/{lifecycle_name}"
+        f":notebook-instance-lifecycle-config/{lifecycle_name}"
     )
 
 
