@@ -4,15 +4,17 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_sns, mock_sqs
+from moto import mock_aws
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from moto.sns.models import (
     DEFAULT_EFFECTIVE_DELIVERY_POLICY,
     DEFAULT_PAGE_SIZE,
 )
+from tests import aws_verified
+from tests.test_sns import sns_sqs_aws_verified
 
 
-@mock_sns
+@mock_aws
 def test_subscribe_sms():
     client = boto3.client("sns", region_name="us-east-1")
     client.create_topic(Name="some-topic")
@@ -26,7 +28,61 @@ def test_subscribe_sms():
     assert "SubscriptionArn" in resp
 
 
-@mock_sns
+@pytest.mark.aws_verified
+@aws_verified
+def test_subscribe_unknown_topic():
+    identity = boto3.client("sts", "us-east-1").get_caller_identity()
+    account_id = identity["Account"]
+    client = boto3.client("sns", region_name="us-east-1")
+    arn = f"arn:aws:sns:us-east-1:{account_id}:some-topic"
+
+    with pytest.raises(ClientError) as exc:
+        client.subscribe(TopicArn=arn, Protocol="sqs", Endpoint="asdf")
+    err = exc.value.response["Error"]
+    assert err["Code"] == "NotFound"
+    assert err["Message"] == "Topic does not exist"
+
+
+@pytest.mark.aws_verified
+@sns_sqs_aws_verified()
+def test_subscribe_unknown_sqs_queue(
+    topic_name=None, topic_arn=None, queue_name=None, queue_arn=None
+):
+    client = boto3.client("sns", region_name="us-east-1")
+
+    # Subscribing to an unknown queue is not a problem
+    unknown_queue = queue_arn.replace(queue_name, "unknown")
+    subscription_arn = client.subscribe(
+        TopicArn=topic_arn, Protocol="sqs", Endpoint=unknown_queue
+    )["SubscriptionArn"]
+
+    # Clean up
+    client.unsubscribe(SubscriptionArn=subscription_arn)
+
+    # Subscribing to something that is not an ARN is a problem though
+    with pytest.raises(ClientError) as exc:
+        client.subscribe(TopicArn=topic_arn, Protocol="sqs", Endpoint="unknown")
+    err = exc.value.response["Error"]
+    assert err["Code"] == "InvalidParameter"
+    assert err["Message"] == "Invalid parameter: SQS endpoint ARN"
+
+
+@pytest.mark.aws_verified
+@sns_sqs_aws_verified()
+def test_subscribe_sqs_queue_url(
+    topic_name=None, topic_arn=None, queue_name=None, queue_arn=None
+):
+    client = boto3.client("sns", region_name="us-east-1")
+
+    queue = boto3.resource("sqs", "us-east-1").Queue(queue_name)
+    with pytest.raises(ClientError) as exc:
+        client.subscribe(TopicArn=topic_arn, Protocol="sqs", Endpoint=queue.url)
+    err = exc.value.response["Error"]
+    assert err["Code"] == "InvalidParameter"
+    assert err["Message"] == "Invalid parameter: SQS endpoint ARN"
+
+
+@mock_aws
 def test_double_subscription():
     client = boto3.client("sns", region_name="us-east-1")
     client.create_topic(Name="some-topic")
@@ -34,16 +90,16 @@ def test_double_subscription():
     arn = resp["TopicArn"]
 
     resp1 = client.subscribe(
-        TopicArn=arn, Protocol="sqs", Endpoint="arn:aws:sqs:elasticmq:000000000000:foo"
+        TopicArn=arn, Protocol="sqs", Endpoint="arn:aws:sqs:us-east-1:000000000000:foo"
     )
     resp2 = client.subscribe(
-        TopicArn=arn, Protocol="sqs", Endpoint="arn:aws:sqs:elasticmq:000000000000:foo"
+        TopicArn=arn, Protocol="sqs", Endpoint="arn:aws:sqs:us-east-1:000000000000:foo"
     )
 
     assert resp1["SubscriptionArn"] == resp2["SubscriptionArn"]
 
 
-@mock_sns
+@mock_aws
 def test_subscribe_bad_sms():
     client = boto3.client("sns", region_name="us-east-1")
     client.create_topic(Name="some-topic")
@@ -79,7 +135,7 @@ def test_subscribe_bad_sms():
     )
 
 
-@mock_sns
+@mock_aws
 def test_creating_subscription():
     conn = boto3.client("sns", region_name="us-east-1")
     conn.create_topic(Name="some-topic")
@@ -104,7 +160,7 @@ def test_creating_subscription():
     assert len(subscriptions) == 0
 
 
-@mock_sns
+@mock_aws
 def test_unsubscribe_from_deleted_topic():
     client = boto3.client("sns", region_name="us-east-1")
     client.create_topic(Name="some-topic")
@@ -146,7 +202,7 @@ def test_unsubscribe_from_deleted_topic():
     client.unsubscribe(SubscriptionArn=subscription_arn)
 
 
-@mock_sns
+@mock_aws
 def test_getting_subscriptions_by_topic():
     conn = boto3.client("sns", region_name="us-east-1")
     conn.create_topic(Name="topic1")
@@ -171,7 +227,7 @@ def test_getting_subscriptions_by_topic():
     assert topic1_subscriptions[0]["Endpoint"] == "http://example1.com/"
 
 
-@mock_sns
+@mock_aws
 def test_subscription_paging():
     conn = boto3.client("sns", region_name="us-east-1")
     conn.create_topic(Name="topic1")
@@ -208,7 +264,7 @@ def test_subscription_paging():
     assert "NextToken" not in topic1_subscriptions
 
 
-@mock_sns
+@mock_aws
 def test_subscribe_attributes():
     client = boto3.client("sns", region_name="us-east-1")
     client.create_topic(Name="some-topic")
@@ -236,7 +292,7 @@ def test_subscribe_attributes():
     )
 
 
-@mock_sns
+@mock_aws
 def test_creating_subscription_with_attributes():
     conn = boto3.client("sns", region_name="us-east-1")
     conn.create_topic(Name="some-topic")
@@ -311,29 +367,27 @@ def test_creating_subscription_with_attributes():
         )
 
 
-@mock_sns
-@mock_sqs
+@mock_aws
 def test_delete_subscriptions_on_delete_topic():
     sqs = boto3.client("sqs", region_name="us-east-1")
     conn = boto3.client("sns", region_name="us-east-1")
 
-    queue = sqs.create_queue(QueueName="test-queue")
+    sqs.create_queue(QueueName="test-queue")
     topic = conn.create_topic(Name="some-topic")
 
-    conn.subscribe(
-        TopicArn=topic.get("TopicArn"), Protocol="sqs", Endpoint=queue.get("QueueUrl")
-    )
+    queue_url = f"arn:aws:sqs:us-east-1:{ACCOUNT_ID}:test-queue"
+    conn.subscribe(TopicArn=topic["TopicArn"], Protocol="sqs", Endpoint=queue_url)
     subscriptions = conn.list_subscriptions()["Subscriptions"]
 
     assert len(subscriptions) == 1
 
-    conn.delete_topic(TopicArn=topic.get("TopicArn"))
+    conn.delete_topic(TopicArn=topic["TopicArn"])
 
     subscriptions = conn.list_subscriptions()["Subscriptions"]
     assert len(subscriptions) == 0
 
 
-@mock_sns
+@mock_aws
 def test_set_subscription_attributes():
     conn = boto3.client("sns", region_name="us-east-1")
     conn.create_topic(Name="some-topic")
@@ -436,7 +490,7 @@ def test_set_subscription_attributes():
         )
 
 
-@mock_sns
+@mock_aws
 def test_subscribe_invalid_filter_policy():
     conn = boto3.client("sns", region_name="us-east-1")
     conn.create_topic(Name="some-topic")
@@ -672,7 +726,7 @@ def test_subscribe_invalid_filter_policy():
         "Invalid parameter: Attributes Reason: FilterPolicy: Value of < must be numeric\n at ..."
     )
 
-    try:
+    with pytest.raises(ClientError) as err_info:
         conn.subscribe(
             TopicArn=topic_arn,
             Protocol="http",
@@ -681,14 +735,13 @@ def test_subscribe_invalid_filter_policy():
                 "FilterPolicy": json.dumps({"store": {"key": [{"exists": None}]}})
             },
         )
-    except ClientError as err:
-        assert err.response["Error"]["Code"] == "InvalidParameter"
-        assert err.response["Error"]["Message"] == (
-            "Invalid parameter: Filter policy scope MessageAttributes does "
-            "not support nested filter policy"
-        )
+    assert err_info.value.response["Error"]["Code"] == "InvalidParameter"
+    assert (
+        err_info.value.response["Error"]["Message"]
+        == "Invalid parameter: Filter policy scope MessageAttributes does not support nested filter policy"
+    )
 
-    try:
+    with pytest.raises(ClientError) as err_info:
         filter_policy = {
             "key_a": ["value_one"],
             "key_b": ["value_two"],
@@ -703,13 +756,13 @@ def test_subscribe_invalid_filter_policy():
             Endpoint="http://example.com/",
             Attributes={"FilterPolicy": json.dumps(filter_policy)},
         )
-    except ClientError as err:
-        assert err.response["Error"]["Code"] == "InvalidParameter"
-        assert err.response["Error"]["Message"] == (
-            "Invalid parameter: FilterPolicy: Filter policy can not have more than 5 keys"
-        )
+    assert err_info.value.response["Error"]["Code"] == "InvalidParameter"
+    assert (
+        err_info.value.response["Error"]["Message"]
+        == "Invalid parameter: FilterPolicy: Filter policy can not have more than 5 keys"
+    )
 
-    try:
+    with pytest.raises(ClientError) as err_info:
         nested_filter_policy = {
             "key_a": {
                 "key_b": {
@@ -732,14 +785,13 @@ def test_subscribe_invalid_filter_policy():
                 "FilterPolicy": json.dumps(nested_filter_policy),
             },
         )
-    except ClientError as err:
-        assert err.response["Error"]["Code"] == "InvalidParameter"
-        assert err.response["Error"]["Message"] == (
-            "Invalid parameter: FilterPolicy: Filter policy is too complex"
-        )
+    assert err_info.value.response["Error"]["Code"] == "InvalidParameter"
+    assert err_info.value.response["Error"]["Message"] == (
+        "Invalid parameter: FilterPolicy: Filter policy is too complex"
+    )
 
 
-@mock_sns
+@mock_aws
 def test_check_not_opted_out():
     conn = boto3.client("sns", region_name="us-east-1")
     response = conn.check_if_phone_number_is_opted_out(phoneNumber="+447428545375")
@@ -748,7 +800,7 @@ def test_check_not_opted_out():
     assert response["isOptedOut"] is False
 
 
-@mock_sns
+@mock_aws
 def test_check_opted_out():
     # Phone number ends in 99 so is hardcoded in the endpoint to return opted
     # out status
@@ -759,7 +811,7 @@ def test_check_opted_out():
     assert response["isOptedOut"] is True
 
 
-@mock_sns
+@mock_aws
 def test_check_opted_out_invalid():
     conn = boto3.client("sns", region_name="us-east-1")
 
@@ -768,7 +820,7 @@ def test_check_opted_out_invalid():
         conn.check_if_phone_number_is_opted_out(phoneNumber="+44742LALALA")
 
 
-@mock_sns
+@mock_aws
 def test_list_opted_out():
     conn = boto3.client("sns", region_name="us-east-1")
     response = conn.list_phone_numbers_opted_out()
@@ -777,7 +829,7 @@ def test_list_opted_out():
     assert len(response["phoneNumbers"]) > 0
 
 
-@mock_sns
+@mock_aws
 def test_opt_in():
     conn = boto3.client("sns", region_name="us-east-1")
     response = conn.list_phone_numbers_opted_out()
@@ -791,7 +843,7 @@ def test_opt_in():
     assert len(response["phoneNumbers"]) < current_len
 
 
-@mock_sns
+@mock_aws
 def test_confirm_subscription():
     conn = boto3.client("sns", region_name="us-east-1")
     response = conn.create_topic(Name="testconfirm")
@@ -808,7 +860,7 @@ def test_confirm_subscription():
     )
 
 
-@mock_sns
+@mock_aws
 def test_get_subscription_attributes_error_not_exists():
     # given
     client = boto3.client("sns", region_name="us-east-1")
