@@ -1,18 +1,19 @@
 import json
 import time
 import uuid
+from unittest import SkipTest
 
 import boto3
+import pytest
+from botocore.exceptions import ClientError
 
-from moto import mock_lambda, mock_logs, mock_sqs
+from moto import mock_aws, settings
 from tests.markers import requires_docker
 from tests.test_awslambda.test_lambda import get_role_name, get_test_zip_file1
 from tests.test_awslambda.utilities import get_test_zip_file_print_event
 
 
-@mock_logs
-@mock_lambda
-@mock_sqs
+@mock_aws
 @requires_docker
 def test_invoke_function_from_sqs_queue():
     logs_conn = boto3.client("logs", region_name="us-east-1")
@@ -71,9 +72,39 @@ def test_invoke_function_from_sqs_queue():
     assert False, "Test Failed"
 
 
-@mock_logs
-@mock_lambda
-@mock_sqs
+@mock_aws(config={"lambda": {"use_docker": False}})
+def test_invoke_fake_function_from_sqs_queue():
+    if not settings.TEST_DECORATOR_MODE:
+        raise SkipTest("Can only set Config in DecoratorMode")
+    logs_conn = boto3.client("logs", region_name="us-east-1")
+    sqs = boto3.resource("sqs", region_name="us-east-1")
+    queue_name = str(uuid.uuid4())[0:6]
+    queue = sqs.create_queue(QueueName=queue_name)
+
+    fn_name = str(uuid.uuid4())[0:6]
+    conn = boto3.client("lambda", region_name="us-east-1")
+    func = conn.create_function(
+        FunctionName=fn_name,
+        Runtime="python3.11",
+        Role=get_role_name(),
+        Handler="lambda_function.lambda_handler",
+        Code={"ZipFile": b"n/a"},
+    )
+
+    conn.create_event_source_mapping(
+        EventSourceArn=queue.attributes["QueueArn"], FunctionName=func["FunctionArn"]
+    )
+
+    queue.send_messages(Entries=[{"Id": "1", "MessageBody": "n/a"}])
+
+    # Because the AWSLambda is never invoked, the log group doesn't even exist
+    with pytest.raises(ClientError) as exc:
+        logs_conn.describe_log_streams(logGroupName=f"/aws/lambda/{fn_name}")
+    err = exc.value.response["Error"]
+    assert err["Message"] == "The specified log group does not exist."
+
+
+@mock_aws
 @requires_docker
 def test_invoke_function_from_sqs_fifo_queue():
     """
